=== modified file '__init__.py'
--- __init__.py	2006-03-22 21:54:32 +0000
+++ __init__.py	2006-03-22 22:04:44 +0000
@@ -22,6 +22,9 @@
 in your ~/.bazaar/plugins/ directory.
 """
 
+# The XMLRPC server address can be overridden by setting the environment
+# variable $BZR_LP_XMLRPL_URL
+
 # see http://bazaar-vcs.org/Specs/BranchRegistrationTool
 
 from bzrlib.commands import Command, Option, register_command

=== modified file 'lp_registration.py'
--- lp_registration.py	2006-03-22 21:54:32 +0000
+++ lp_registration.py	2006-03-22 22:04:44 +0000
@@ -16,6 +16,7 @@
 
 
 from getpass import getpass
+import os
 from urlparse import urlsplit, urlunsplit
 from urllib import unquote, quote
 import xmlrpclib
@@ -34,8 +35,7 @@
 
     # NB: this should always end in a slash to avoid xmlrpclib appending
     # '/RPC2'
-    # DEFAULT_SERVICE_URL = 'http://xmlrpc.launchpad.net/bazaar/'
-    DEFAULT_SERVICE_URL = 'http://10.65.252.255:8081/'
+    DEFAULT_SERVICE_URL = 'http://xmlrpc.launchpad.net/bazaar/'
 
     # None means to use the xmlrpc default, which is almost always what you
     # want.  But it might be useful for testing.
@@ -58,7 +58,6 @@
         self.author_email = author_email
         self.product_name = product_name
         # XXX: these should perhaps be in the registration method
-        self.service_url = self.DEFAULT_SERVICE_URL
         self.registrant_email = 'testuser@launchpad.net'
         self.registrant_password = 'testpassword'
 
@@ -74,6 +73,19 @@
                 self.product_name,
                )
 
+    def _get_service_url(self):
+        """Return the http or https url for the xmlrpc server.
+
+        This does not include the username/password credentials.
+        """
+        key = 'BZR_LP_XMLRPC_URL'
+        if key in os.environ:
+            return os.environ[key]
+        else:
+            return self.DEFAULT_SERVICE_URL
+
+    service_url = property(_get_service_url)
+
     def submit(self, transport=None):
         """Submit registration request to the server.
         

